'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var helper = require('@tarojs/helper');
var shared = require('@tarojs/shared');

const spawn = require('cross-spawn');
const detectPort = require('detect-port');
function index (ctx, options) {
    if (process.env.NODE_ENV === 'production' || options.enabled === false)
        return;
    const hostname = JSON.stringify(options.hostname || 'localhost');
    const port = Number(options.port || '8098');
    detectPort(port, (err, availablePort) => {
        if (err) {
            // eslint-disable-next-line no-console
            console.log(`detectport 错误：${err}`);
        }
        if (availablePort === port) {
            // eslint-disable-next-line no-console
            console.log(helper.chalk.yellow('\n提示  ') + '正在启动 vue-devtools...\n');
            spawn(require.resolve('@vue/devtools/bin'), { env: Object.assign(Object.assign({}, process.env), { PORT: port }) });
        }
    });
    ctx.registerMethod({
        name: 'onSetupClose',
        fn(platform) {
            injectRuntimePath(platform);
        }
    });
    ctx.modifyWebpackChain(({ chain }) => {
        chain
            .plugin('definePlugin')
            .tap(args => {
            const config = args[0];
            config.__VUE_DEVTOOLS_HOSTNAME__ = hostname;
            config.__VUE_DEVTOOLS_PORT__ = port;
            config.ENABLE_SIZE_APIS = true;
            config.ENABLE_CONTAINS = true;
            return args;
        });
        chain
            .plugin('providerPlugin')
            .tap(args => {
            const config = args[0];
            config.globalThis = ['@tarojs/runtime', 'window'];
            config.HTMLElement = ['@tarojs/runtime', 'TaroElement'];
            return args;
        });
    });
    ctx.modifyRunnerOpts(({ opts }) => {
        var _a;
        if (!(opts === null || opts === void 0 ? void 0 : opts.compiler))
            return;
        if (shared.isString(opts.compiler)) {
            opts.compiler = {
                type: opts.compiler
            };
        }
        if (opts.compiler.type === 'webpack5') {
            (_a = opts.compiler).prebundle || (_a.prebundle = {});
            const prebundle = opts.compiler.prebundle;
            if (prebundle.enable === false)
                return;
            prebundle.webpack || (prebundle.webpack = {});
            const webpackConfig = prebundle.webpack;
            webpackConfig.provide || (webpackConfig.provide = []);
            webpackConfig.provide.push(function (obj, taroRuntimeBundlePath) {
                obj.globalThis = [taroRuntimeBundlePath, 'window'];
                obj.HTMLElement = [taroRuntimeBundlePath, 'TaroElement'];
            });
        }
    });
}
function injectRuntimePath(platform) {
    const injectedPath = 'post:@tarojs/plugin-vue-devtools/dist/runtime';
    if (shared.isArray(platform.runtimePath)) {
        platform.runtimePath.push(injectedPath);
    }
    else if (shared.isString(platform.runtimePath)) {
        platform.runtimePath = [platform.runtimePath, injectedPath];
    }
}

exports.default = index;
//# sourceMappingURL=index.js.map
